@@ -2,7 +2,7 @@
 # There's no way to ignore "F401 '...' imported but unused" warnings in this
 # module, but to preserve other warnings. So, don't check this module at all.
 
-__version__ = "0.12.0"
+__version__ = "0.13.0"
 
 from .accelerator import Accelerator
 from .big_modeling import cpu_offload, disk_offload, dispatch_model, init_empty_weights, load_checkpoint_and_dispatch
@@ -16,6 +16,11 @@ from .utils import (
     InitProcessGroupKwargs,
     find_executable_batch_size,
     infer_auto_device_map,
+    is_rich_available,
     load_checkpoint_in_model,
     synchronize_rng_states,
 )
+
+
+if is_rich_available():
+    from .utils import rich
